@@ -9,35 +9,35 @@ pub trait FrameRate {
 pub struct FrameRate2400;
 
 impl FrameRate for FrameRate2400 {
-    const FPS: u32 = 24;
+  const FPS: u32 = 24;
 }
 
 #[derive(Debug, PartialEq)]
 pub struct FrameRate2500;
 
 impl FrameRate for FrameRate2500 {
-    const FPS: u32 = 25;
+  const FPS: u32 = 25;
 }
 
 #[derive(Debug, PartialEq)]
 pub struct FrameRate3000;
 
 impl FrameRate for FrameRate3000 {
-    const FPS: u32 = 30;
+  const FPS: u32 = 30;
 }
 
 #[derive(Debug, PartialEq)]
 pub struct FrameRate5000;
 
 impl FrameRate for FrameRate5000 {
-    const FPS: u32 = 50;
+  const FPS: u32 = 50;
 }
 
 #[derive(Debug, PartialEq)]
 pub struct FrameRate6000;
 
 impl FrameRate for FrameRate6000 {
-    const FPS: u32 = 60;
+  const FPS: u32 = 60;
 }
 
 #[derive(Debug, Clone, PartialEq, Serialize)]
@@ -48,7 +48,7 @@ pub struct Timecode<FrameRate> {
   pub frame: u8,
   pub drop_frame: bool,
   pub color_frame: bool,
-  frame_rate: marker::PhantomData::<FrameRate>,
+  frame_rate: marker::PhantomData<FrameRate>,
 }
 
 impl<FrameRate> ToString for Timecode<FrameRate> {
@@ -65,10 +65,8 @@ impl<FrameRate> ToString for Timecode<FrameRate> {
   }
 }
 
-impl<FrameRate> From<u32> for Timecode<FrameRate> {
-  fn from(frames: u32) -> Self {
-    let fps = 24;
-
+impl<FrameRate> From<(u32, u32)> for Timecode<FrameRate> {
+  fn from((frames, fps): (u32, u32)) -> Self {
     let hours = frames / (60 * 60 * fps);
     let minutes = (frames / (60 * fps)) - hours * 60;
     let seconds = (frames / fps) - minutes * 60 - hours * 60 * 60;
@@ -85,7 +83,7 @@ impl<FrameRate> From<u32> for Timecode<FrameRate> {
       frame: frame as u8,
       drop_frame,
       color_frame,
-      frame_rate: marker::PhantomData
+      frame_rate: marker::PhantomData,
     }
   }
 }
@@ -140,43 +138,43 @@ impl<FrameRate> Timecode<FrameRate> {
 
 #[test]
 fn timecode_from_frame() {
-  let t1 = Timecode::<FrameRate2400>::from(24 * 60 * 60 * 10);
+  let t1 = Timecode::<FrameRate2400>::from((24 * 60 * 60 * 10, 24));
   assert_eq!(t1.hours, 10);
   assert_eq!(t1.minutes, 0);
   assert_eq!(t1.seconds, 0);
   assert_eq!(t1.frame, 0);
 
-  let t1 = Timecode::<FrameRate2400>::from(24 * 60 * 60);
+  let t1 = Timecode::<FrameRate2400>::from((24 * 60 * 60, 24));
   assert_eq!(t1.hours, 1);
   assert_eq!(t1.minutes, 0);
   assert_eq!(t1.seconds, 0);
   assert_eq!(t1.frame, 0);
 
-  let t2 = Timecode::<FrameRate2400>::from(24 * 60 * 60 - 1);
+  let t2 = Timecode::<FrameRate2400>::from((24 * 60 * 60 - 1, 24));
   assert_eq!(t2.hours, 0);
   assert_eq!(t2.minutes, 59);
   assert_eq!(t2.seconds, 59);
   assert_eq!(t2.frame, 23);
 
-  let t2 = Timecode::<FrameRate2400>::from(24 * 60);
+  let t2 = Timecode::<FrameRate2400>::from((24 * 60, 24));
   assert_eq!(t2.hours, 0);
   assert_eq!(t2.minutes, 1);
   assert_eq!(t2.seconds, 0);
   assert_eq!(t2.frame, 0);
 
-  let t2 = Timecode::<FrameRate2400>::from(24 * 60 - 1);
+  let t2 = Timecode::<FrameRate2400>::from((24 * 60 - 1, 24));
   assert_eq!(t2.hours, 0);
   assert_eq!(t2.minutes, 0);
   assert_eq!(t2.seconds, 59);
   assert_eq!(t2.frame, 23);
 
-  let t3 = Timecode::<FrameRate2400>::from(24);
+  let t3 = Timecode::<FrameRate2400>::from((24, 24));
   assert_eq!(t3.hours, 0);
   assert_eq!(t3.minutes, 0);
   assert_eq!(t3.seconds, 1);
   assert_eq!(t3.frame, 0);
 
-  let t3 = Timecode::<FrameRate2400>::from(23);
+  let t3 = Timecode::<FrameRate2400>::from((23, 24));
   assert_eq!(t3.hours, 0);
   assert_eq!(t3.minutes, 0);
   assert_eq!(t3.seconds, 0);
